@@ -2,8 +2,11 @@ from .file.file import File
 from .result.parser import PaymentParser
 from .payment.transfer import Transfer
 from .payment.barCodePayment import BarCodePayment
+from .payment.nonBarCodePayment import NonBarCodePayment
 from .payment.issPayment import IssPayment
 from .payment.dasPayment import DasPayment
-from .payment.darfPayment import DarfBarCodePayment
+from .payment.fgtsPayment import FgtsPayment
+from .payment.darfPayment import DarfPayment, DarfBarCodePayment
+from .payment.gpsPayment import GpsBarCodePayment
 from .payment.chargePayment import ChargePayment
 from .payment.utilityPayment import UtilityPayment
